<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>PasswordWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="62"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="145"/>
        <source>Passwords do not match</source>
        <translation>Fjalëkalimet nuk përputhen</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="71"/>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>Ndihmëza do të jetë e dukshme për krejt përdoruesit. Mos përfshini fjalëkalimin këtu.</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="89"/>
        <source>New Password</source>
        <translation>Fjalëkalimi i Ri</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="111"/>
        <source>Repeat Password</source>
        <translation>Rijepeni Fjalëkalimin</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="119"/>
        <source>Password Hint</source>
        <translation>Ndihmëz Fjalëkalimi</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="128"/>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="129"/>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/passwordwidget.cpp" line="130"/>
        <source>Optional</source>
        <translation>Opsionale</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="78"/>
        <source>Password cannot be empty</source>
        <translation>Fjalëkalimi s’mund të jetë i zbrazët</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="79"/>
        <source>Password must have at least %1 characters</source>
        <translation>Fjalëkalimi duhet të ketë të paktën %1 shenja</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="80"/>
        <source>Password must be no more than %1 characters</source>
        <translation>Fjalëkalimi s’duhet të jetë më i madh se %1 shenja</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="81"/>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Fjalëkalimi mund të përmbajë vetëm shkronja anglisht (bëhet dallimi mes shkrimit me të mëdha dhe të vogla), numra ose simbole speciale (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="82"/>
        <source>No more than %1 palindrome characters please</source>
        <translation>Ju lutemi, jo më shumë se %1 shenja palindromike</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="83"/>
        <source>No more than %1 monotonic characters please</source>
        <translation>Ju lutemi, jo më shumë se %1 shenja monotonike</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="84"/>
        <source>No more than %1 repeating characters please</source>
        <translation>Ju lutemi, jo më shumë se %1 shenja të përsëritura</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="85"/>
        <source>The password should differ from the username</source>
        <translation>Fjalëkalimi duhet të jetë i ndryshëm nga emri i përdoruesit</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="91"/>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Fjalëkalimi duhet të përmbajë vetëm shkronja të mëdha, shkronja të vogla, numra dhe simbole (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="92"/>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>Fjalëkalimi s’duhet të përmbajë më shumë se 4 shenja palindromike</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="93"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="96"/>
        <source>Do not use common words and combinations as password</source>
        <translation>Mos përdorni si fjalëkalim fjalë dhe kombinime të zakonshme</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="94"/>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="95"/>
        <source>Create a strong password please</source>
        <translation>Ju lutemi, krijoni një fjalëkalim të fortë</translation>
    </message>
    <message>
        <location filename="../src/frame/window/modules/accounts/pwqualitymanager.cpp" line="102"/>
        <source>It does not meet password rules</source>
        <translation>S’plotëson rregullat për fjalëkalime</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/reset-password-dialog/utils.h" line="72"/>
        <source>It cannot be empty</source>
        <translation>S’mund të jetë e zbrazët</translation>
    </message>
</context>
<context>
    <name>ResetPasswordDialog</name>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="119"/>
        <source>Resetting the password will clear the data stored in the keyring</source>
        <translation>Ricaktimi i fjalëkalimit do të spastrojë të dhënat e depozituara te vargu i kyçeve</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="121"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="224"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="130"/>
        <source>Security Questions</source>
        <translation>Pyetje Sigurie</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="165"/>
        <source>Reset Password</source>
        <translation>Ricaktoni Fjalëkalimin</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="166"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <source>Next</source>
        <translation>Pasuesi</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="169"/>
        <source>Reset Password By UOS ID</source>
        <translation>Ricaktoni Fjalëkalimin Përmes ID UOS</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="170"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="209"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="212"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="220"/>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="227"/>
        <source>Reset</source>
        <translation>Ricaktojeni</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="176"/>
        <source>Resetting the password will clear the data stored in your keyring, and you should log in again, please save files in advance</source>
        <translation>Ricaktimi i fjalëkalimit do të spastrojë të dhënat e ruajtura në vargun tuaj të kyçeve dhe do të duhet të ribëni hyrjen, ju lutemi, ruani paraprakisht kartelat</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="177"/>
        <source>Confirm and Reset</source>
        <translation>Ripohojeni dhe Kryeni Ricaktimin</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/resetpassworddialog.cpp" line="302"/>
        <source>Successfully reset, please log in and unlock with the new password</source>
        <translation>U ricaktua me sukses, ju lutemi, bëni hyrjen dhe shkyçeni me fjalëkalimin e ri</translation>
    </message>
</context>
<context>
    <name>SecurityLevelItem</name>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="73"/>
        <source>Weak</source>
        <translation>I dobët</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="83"/>
        <source>Medium</source>
        <translation>Çka</translation>
    </message>
    <message>
        <location filename="../src/frame/widgets/securitylevelitem.cpp" line="93"/>
        <source>Strong</source>
        <translation>I fortë</translation>
    </message>
</context>
<context>
    <name>SecurityQuestionsWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="126"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="127"/>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="128"/>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="130"/>
        <source>What&apos;s the name of the city where you were born?</source>
        <translation>Cili është emri i qytetit ku lindët?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="131"/>
        <source>What&apos;s the name of the first school you attended?</source>
        <translation>Cili është emri i shkollës së parë që ndoqët?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="132"/>
        <source>Who do you love the most in this world?</source>
        <translation>Kë doni më shumë në këtë botë?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="133"/>
        <source>What&apos;s your favorite animal?</source>
        <translation>Cila është kafsha juaj e parapëlqyer?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="134"/>
        <source>What&apos;s your favorite song?</source>
        <translation>Cila është kënga juaj e parapëlqyer?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="135"/>
        <source>What&apos;s your nickname?</source>
        <translation>Cila është nofka juaj?</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="185"/>
        <source>Wrong answer</source>
        <translation>Përgjigje e gabuar</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/securityquestionswidget.cpp" line="200"/>
        <source>Keep the answer under 30 characters</source>
        <translation>Përgjigjen mbajeni nën 30 shenja</translation>
    </message>
</context>
<context>
    <name>UnionIDWidget</name>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="62"/>
        <source>Phone/Email</source>
        <translation>Telefoni/Email</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="68"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="135"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="284"/>
        <source>Get Code</source>
        <translation>Merrni Kod</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="88"/>
        <source>Connecting to the Internet...</source>
        <translation>Po lidhet në Internet…</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="100"/>
        <source>The user account is not linked to UOS ID</source>
        <translation>Llogaria e përdoruesit s’është e lidhur me UOS ID</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="113"/>
        <source>Network disconnected, please retry after connected</source>
        <translation>Rrjeti u shkëput, ju lutemi, riprovoni pasi të jetë lidhur</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="133"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="134"/>
        <source>Required</source>
        <translation>E domosdoshme</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="175"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="192"/>
        <source>Phone/Email format is incorrect</source>
        <translation>Formati për Telefon/Email është i pasaktë</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="246"/>
        <source>System error</source>
        <translation>Gabim sistemi</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="248"/>
        <source>Login expired, please sign in to the UOS ID again</source>
        <translation>Hyrja skadoi, ju lutemi, rihyni te UOS ID</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="250"/>
        <source>Network error</source>
        <translation>Gabim rrjeti</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="252"/>
        <source>You have reached the number limit to get the code today</source>
        <translation>Keni mbërritur në kufirin e numrit për marrje kodesh për sot</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="253"/>
        <source>The UOS ID is not linked to a user account</source>
        <translation>UOS ID s’është e lidhur me ndonjë llogari përdoruesi</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="287"/>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="329"/>
        <source>Resend (%1s)</source>
        <translation>Ridërgoje (%1s)</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="349"/>
        <source>Failed to get the code</source>
        <translation>S’u arrit të merrej kod</translation>
    </message>
    <message>
        <location filename="../src/reset-password-dialog/unionidwidget.cpp" line="374"/>
        <source>Wrong verification code</source>
        <translation>Kod i gabuar verifikimi</translation>
    </message>
</context>
</TS>